# Tests by default. No tests: rpmbuild -ba --define 'dotests 0' *.spec
%{!?dotests: %define dotests 1}

%global __make %{_bindir}/make

Summary: The Squid proxy caching server.
Name: squid
Version:	6.9
Release:	1
Epoch: 6
License: GPLv2
Group: System Environment/Daemons
URL: https://www.squid-cache.org/
Source:	https://www.squid-cache.org/Versions/v6/squid-%{version}.tar.xz
Source2: getopt_long.c
Patch1: squid-5.8-perlpath.patch
Patch2: squid-location.patch
Patch3: %{name}-6.9-aix.patch
Patch4: SQUID-2018_3.patch
Patch5: %{name}-4.8-ifnet.patch
Patch6: %{name}-6.9-addrlen.patch
Patch7: %{name}-6.6-testcase.patch
Patch8: squid-6.6-atomic.patch
Patch9: squid-6.6-msg_dontwait.patch
%if %{toolchain} == "gcc"
BuildRequires:	libgcc >= 10.3.0
%endif
%if %{toolchain} == "gcc"
BuildRequires:	libstdc++ >= 10.3.0
%endif
Requires:	db >= 5.3.28
Requires:	expat >= 2.6.2
Requires:	openldap >= 2.5.16
Requires:	cyrus-sasl >= 2.1.28
Requires:	libxml2 >= 2.10.4
%if %{toolchain} == "gcc"
Requires:	libgcc >= 10.3.0
%endif
%if %{toolchain} == "gcc"
Requires:	libstdc++ >= 10.3.0
%endif
Requires:	gnutls >= 3.8.2
Requires:	nettle >= 3.9.1
Requires:	bash
Prefix: %{_prefix}
Obsoletes: squid-novm

%description
Squid is a high-performance proxy caching server for web clients,
supporting FTP, gopher, and HTTP data objects. Unlike traditional
caching software, Squid handles all requests in a single,
non-blocking, I/O-driven process. Squid keeps meta data and especially
hot objects cached in RAM, caches DNS lookups, supports non-blocking
DNS lookups, and implements negative caching of failed requests.

Squid consists of a main server program squid, a Domain Name System
lookup program (dnsserver), a program for retrieving FTP data
(ftpget), and some management and client tools.

%ifarch ia64
  %define stdlib lib/ia64l32
  %define liblink ../../..
  %define DEFCCIA cc
  %define DEFCC %{DEFCCIA}
%else
  %define stdlib lib
  %define liblink ../..
  %define DEFCC cc
%endif

%prep
%setup -q
%patch1 -p1
%patch2 -p0
%patch3 -p0
#%patch4 -p1
#%patch5 -p0
%patch7 -p0
%patch9 -p1

cp %{SOURCE2} .
rm -rf   /tmp/%{name}-%{version}-32bit
cp -pr . /tmp/%{name}-%{version}-32bit
rm -fr *
mv       /tmp/%{name}-%{version}-32bit 32bit
cp -pr 32bit 64bit

cd 64bit
%patch6 -p0

cd ../32bit
%patch8 -p0

%build
export CONFIG_SHELL=/opt/freeware/bin/bash
export CONFIG_ENV_ARGS=/opt/freeware/bin/bash
export LIBXML2_LIBS="/opt/freeware/lib/libxml2.a"
# Use the default compiler for this platform - gcc otherwise
if [[ -z "$CC" ]]
then
    if test "X`type %{DEFCC} 2>/dev/null`" != 'X'; then
       export CC=%{DEFCC}
    else 
       export CC=gcc
    fi
fi
if [[ "$CC" != "gcc" ]]
then
%ifarch ia64
       export CC64="$CC -q64"
%endif
       export RPM_OPT_FLAGS=`echo $RPM_OPT_FLAGS | sed 's:-fsigned-char::'`
fi

# build on 64bit mode
cd 64bit
export OBJECT_MODE=64
export CFLAGS="$RPM_OPT_FLAGS"
export CC="%{__cc__} -maix64 -O2 -pthread"
export CXX="%{__cxx__} -maix64 -O2 -pthread"
export LDFLAGS="-L/opt/freeware/lib/pthread/ppc64 -L/opt/freeware/lib64 -L/opt/freeware/lib -Wl,-blibpath:/opt/freeware/lib/pthread/ppc64:/opt/freeware/lib64:/opt/freeware/lib:/usr/lib:/lib -lbsd"

%ifos linux
%configure \
   --exec_prefix=/usr --bindir=/usr/sbin --libexecdir=/usr/lib/squid \
   --localstatedir=/var --sysconfdir=/etc/squid \
   --enable-poll --enable-snmp --enable-removal-policies="heap,lru" \
   --enable-storeio="aufs,coss,diskd,ufs" \
   --enable-delay-pools --enable-linux-netfilter \
   --enable-htcp --enable-carp --with-pthreads \
   --enable-auth-modules="LDAP,NCSA,PAM,SMB,MSNT"  # --enable-icmp
%else
%configure --localstatedir=/var --sysconfdir=%{prefix}/etc/squid \
   --libexecdir=%{prefix}/lib64/squid --bindir=%{prefix}/sbin \
   --enable-delay-pools --disable-strict-error-checking --disable-auth --disable-loadable-modules \
   --with-swapdir=/var/spool/squid
%endif

%ifos linux
# Some versions of autoconf fail to detect sys/resource.h correctly;
# apparently because it generates a compiler warning.
if [ -e /usr/include/sys/resource.h ]; then
cat >>include/autoconf.h <<EOF
#ifndef HAVE_SYS_RESOURCE_H
#define HAVE_SYS_RESOURCE_H 1
#define HAVE_STRUCT_RUSAGE 1
#endif
EOF
fi
%endif

make -j8

mkdir faq
cp $RPM_SOURCE_DIR/FAQ.sgml faq
cd faq
%ifos linux
sgml2html FAQ.sgml
%endif
cd -
if [ "%{dotests}" == 1 ]
then
    (gmake -k check LDFLAGS="-Wl,-berok $LDFLAGS" || true)
fi

#build on 32bit mode
export OBJECT_MODE=32
cd ../32bit
export CC="%{__cc__} -maix32 -O2 -D_LARGE_FILES -pthread"
export CXX="%{__cxx__} -maix32 -O2 -D_LARGE_FILES -pthread"
export LDFLAGS="-L/opt/freeware/lib/pthread -L/opt/freeware/lib -Wl,-bmaxdata:0x80000000 -Wl,-blibpath:/opt/freeware/lib/pthread:/opt/freeware/lib:/usr/lib:/lib -lbsd"
%ifos linux
%configure \
   --exec_prefix=/usr --bindir=/usr/sbin --libexecdir=/usr/lib/squid \
   --localstatedir=/var --sysconfdir=/etc/squid \
   --enable-poll --enable-snmp --enable-removal-policies="heap,lru" \
   --enable-storeio="aufs,coss,diskd,ufs" \
   --enable-delay-pools --enable-linux-netfilter \
   --enable-htcp --enable-carp --with-pthreads \
   --enable-auth-modules="LDAP,NCSA,PAM,SMB,MSNT"  # --enable-icmp
%else
%configure --localstatedir=/var --sysconfdir=%{prefix}/etc/squid \
   --libexecdir=%{prefix}/lib/squid --bindir=%{prefix}/sbin --disable-auth \
   --enable-delay-pools --disable-strict-error-checking --disable-loadable-modules --disable-auth \
   --with-swapdir=/var/spool/squid
%endif

%ifos linux   
# Some versions of autoconf fail to detect sys/resource.h correctly;
# apparently because it generates a compiler warning.
if [ -e /usr/include/sys/resource.h ]; then
cat >>include/autoconf.h <<EOF
#ifndef HAVE_SYS_RESOURCE_H
#define HAVE_SYS_RESOURCE_H 1
#define HAVE_STRUCT_RUSAGE 1
#endif
EOF
fi
%endif

make -j8

mkdir faq
cp $RPM_SOURCE_DIR/FAQ.sgml faq
cd faq 
%ifos linux
sgml2html FAQ.sgml
%endif
cd -
if [ "%{dotests}" == 1 ]
then
    (gmake -k check LDFLAGS="-Wl,-berok $LDFLAGS" || true)
fi

%install
rm -rf $RPM_BUILD_ROOT

#Install on 64bit mode
cd 64bit
export OBJECT_MODE=64
%ifos linux
%make_install  \
        sysconfdir=$RPM_BUILD_ROOT/etc/squid \
        localstatedir=$RPM_BUILD_ROOT/var \
        bindir=$RPM_BUILD_ROOT/usr/sbin \
        libexecdir=$RPM_BUILD_ROOT/usr/lib/squid

mv $RPM_BUILD_ROOT/usr/sbin/*auth $RPM_BUILD_ROOT/usr/lib/squid
%else
%make_install \
        sysconfdir=%{_prefix}/etc/squid \
        localstatedir=/var \
        bindir=%{_prefix}/sbin \
        libexecdir=%{_prefix}/lib64/squid
%endif

(
    cd  ${RPM_BUILD_ROOT}/%{_prefix}/sbin
    for fic in $(ls -1| grep -v -e _32 -e _64)
    do
	mv $fic "$fic"_64
    done
)

#Install on 32bit mode
cd ../32bit
export OBJECT_MODE=32

%ifos linux
%make_install  \
	sysconfdir=$RPM_BUILD_ROOT/etc/squid \
	localstatedir=$RPM_BUILD_ROOT/var \
	bindir=$RPM_BUILD_ROOT/usr/sbin \
	libexecdir=$RPM_BUILD_ROOT/usr/lib/squid

mv $RPM_BUILD_ROOT/usr/sbin/*auth $RPM_BUILD_ROOT/usr/lib/squid
%else
%make_install \
	sysconfdir=%{_prefix}/etc/squid \
	localstatedir=/var \
	bindir=%{_prefix}/sbin \
	libexecdir=%{_prefix}/lib/squid
%endif

/usr/bin/strip -X32_64 $RPM_BUILD_ROOT%{prefix}/sbin/* $RPM_BUILD_ROOT%{prefix}/lib64/squid/* $RPM_BUILD_ROOT%{prefix}/lib/squid/* || :

cd errors
for i in *; do
   if [ -d $i ]; then
       mkdir -p $RPM_BUILD_ROOT%{prefix}/etc/squid/errors/$i
       install -m 644 $i/* $RPM_BUILD_ROOT%{prefix}/etc/squid/errors/$i
   fi
done


(
    cd  ${RPM_BUILD_ROOT}/%{_prefix}/sbin
    for fic in $(ls -1| grep -v -e _32 -e _64)
    do
	mv $fic "$fic"_32
	ln -sf "$fic"_64 $fic
    done
)

(
cd $RPM_BUILD_ROOT
mkdir -p etc
cd etc
ln -sf ..%{prefix}/etc/squid .
cd -
)

mkdir -p $RPM_BUILD_ROOT/var/log/squid
mkdir -p $RPM_BUILD_ROOT/var/spool/squid


%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,system)
%config(noreplace) %{prefix}/etc/squid/squid.conf
%config(noreplace) %{prefix}/etc/squid/mime.conf
%config(noreplace) %{prefix}/etc/squid/cachemgr.conf
%config(noreplace) %{prefix}/etc/squid/cachemgr.conf.default
%config(noreplace) %{prefix}/etc/squid/errorpage.css
%config(noreplace) %{prefix}/etc/squid/errorpage.css.default
%{prefix}/etc/squid/squid.conf.documented
%config %{prefix}/share/mib.txt
%{prefix}/etc/squid/squid.conf.default
%{prefix}/etc/squid/mime.conf.default
#%{prefix}/etc/squid/errors
%{prefix}/share/icons
%{prefix}/share/errors
%{prefix}/lib/squid/*
%{prefix}/lib64/squid/*
%{prefix}/sbin/*
%doc 32bit/faq/* 32bit/README 32bit/INSTALL 32bit/ChangeLog 32bit/QUICKSTART 32bit/doc/*
%doc 32bit/CONTRIBUTORS 32bit/COPYING 32bit/CREDITS
%doc 32bit/contrib/url-normalizer.pl 32bit/contrib/user-agents.pl
%attr(750,nobody,nobody) %dir /var/log/squid
%attr(750,nobody,nobody) %dir /var/spool/squid
/etc/squid
%{_mandir}/*/*

%post
echo "\n From squid version 5.8 onwards, disk cache and coredump directories are set to /var/spool/squid  by default. \n"

%preun
if [ $1 = 0 ] ; then
	rm -rf /var/log/squid/*
fi

%changelog
* Sun May 05 2024 Reshma V Kumar <reskumar@in.ibm.com> - 6.9-1 
- Update to version 6.9 to fix CVE-2024-25111

* Mon Mar 04 2024 Reshma V Kumar <reskumar@in.ibm.com> - 6.6-1 
- Update to version 6.6

* Fri Jul 21 2023 Reshma V Kumar <reskumar@in.ibm.com> - 5.8-1
- Update to version 5.8
- Build with latest libxml2

* Fri Jun 25 2021 Reshma V Kumar <reskumar@in.ibm.com> - 4.15-1
- Update to fix CVE-2021-31808,CVE-2021-28652,CVE-2021-31806,CVE-2021-28651,
- CVE-2021-31807,CVE-2021-28662,CVE-2021-33620

* Mon Apr 19 2021 Reshma V Kumar <reskumar@in.ibm.com> - 4.14-1
- Update to fix CVE-2020-25097

* Tue Feb 09 2021 Reshma V Kumar <reskumar@in.ibm.com> - 4.13-1
- Update to fix CVE-2020-14059,CVE-2020-14058,CVE-2020-24606,CVE-2020-15810,CVE-2020-15811
- Stop shipping files in /usr directory

* Mon Aug 03 2020 Reshma V Kumar <reskumar@in.ibm.com> - 4.11-1
- Update to fix CVE-2020-8517,CVE-2020-8450,CVE-2020-8449,CVE-2019-12528,
- CVE-2019-12520,CVE-2020-11945,CVE-2019-12519,CVE-2019-12521,CVE-2019-12522

* Mon Dec 09 2019 Reshma V Kumar <reskumar@in.ibm.com>-4.9-1
- Update to fix CVE-2019-18679

* Tue Oct 16 2019 Reshma V Kumar <reskumar@in.ibm.com>-4.8-1
- Update to fix CVE-2019-12854, CVE-2019-12525, CVE-2019-12529, CVE-2019-12527

* Tue Jan 01 2019 Reshma V Kumar <reskumar@in.ibm.com>-4.4-1
- Update to fix CVE-2018-19132, CVE-2018-19131

* Mon Aug 13 2018 Reshma V Kumar <reskumar@in.ibm.com>-4.1-1
- Update to latest version

* Tue May 08 2018 Reshma V Kumar <reskumar@in.ibm.com>
- Rebuild with patch to fix CVE-2018-1172

* Wed Jul 24 2002 David Clissold <cliss@austin.ibm.com>
- 2.4.STABLE7-2: enable delay-pools as per special request.

* Mon Jul 08 2002 David Clissold <cliss@austin.ibm.com>
- Update to 2.4.STABLE7

* Wed Apr 10 2002 David Clissold <cliss@austin.ibm.com>
- Update to 2.4.STABLE4

* Thu Sep 06 2001 David Clissold <cliss@austin.ibm.com>
- Update to 2.4.STABLE2

* Tue Jun 18 2001 David Clissold <cliss@austin.ibm.com>
- Initial build for AIX Toolbox

* Tue Apr 24 2001 Bill Nottingham <notting@redhat.com>
- update to 2.4.STABLE1 + patches
- enable some more configure options (#24981)
- oops, ship /etc/sysconfig/squid

* Fri Mar  2 2001 Nalin Dahyabhai <nalin@redhat.com>
- rebuild in new environment

* Tue Feb  6 2001 Trond Eivind Glomsrd <teg@redhat.com>
- improve i18n
- make the initscript use the standard OK/FAILED

* Tue Jan 23 2001 Bill Nottingham <notting@redhat.com>
- change i18n mechanism

* Fri Jan 19 2001 Bill Nottingham <notting@redhat.com>
- fix path references in QUICKSTART (#15114)
- fix initscript translations (#24086)
- fix shutdown logic (#24234), patch from <jos@xos.nl>
- add /etc/sysconfig/squid for daemon options & shutdown timeouts
- three more bugfixes from the Squid people
- update FAQ.sgml
- build and ship auth modules (#23611)

* Thu Jan 11 2001 Bill Nottingham <notting@redhat.com>
- initscripts translations

* Mon Jan  8 2001 Bill Nottingham <notting@redhat.com>
- add patch to use mkstemp (greg@wirex.com)

* Fri Dec 01 2000 Bill Nottingham <notting@redhat.com>
- rebuild because of broken fileutils

* Sat Nov 11 2000 Bill Nottingham <notting@redhat.com>
- fix the acl matching cases (only need the second patch)

* Tue Nov  7 2000 Bill Nottingham <notting@redhat.com>
- add two patches to fix domain ACLs
- add 2 bugfix patches from the squid people

* Fri Jul 28 2000 Bill Nottingham <notting@redhat.com>
- clean up init script; fix condrestart
- update to STABLE4, more bugfixes
- update FAQ

* Tue Jul 18 2000 Nalin Dahyabhai <nalin@redhat.com>
- fix syntax error in init script
- finish adding condrestart support

* Fri Jul 14 2000 Bill Nottingham <notting@redhat.com>
- move initscript back

* Wed Jul 12 2000 Prospector <bugzilla@redhat.com>
- automatic rebuild

* Thu Jul  6 2000 Bill Nottingham <notting@redhat.com>
- prereq /etc/init.d
- add bugfix patch
- update FAQ

* Thu Jun 29 2000 Bill Nottingham <notting@redhat.com>
- fix init script

* Tue Jun 27 2000 Bill Nottingham <notting@redhat.com>
- don't prereq new initscripts

* Mon Jun 26 2000 Bill Nottingham <notting@redhat.com>
- initscript munging

* Sat Jun 10 2000 Bill Nottingham <notting@redhat.com>
- rebuild for exciting FHS stuff

* Wed May 31 2000 Bill Nottingham <notting@redhat.com>
- fix init script again (#11699)
- add --enable-delay-pools (#11695)
- update to STABLE3
- update FAQ

* Fri Apr 28 2000 Bill Nottingham <notting@redhat.com>
- fix init script (#11087)

* Fri Apr  7 2000 Bill Nottingham <notting@redhat.com>
- three more bugfix patches from the squid people
- buildprereq jade, sgmltools

* Sun Mar 26 2000 Florian La Roche <Florian.LaRoche@redhat.com>
- make %pre more portable

* Thu Mar 16 2000 Bill Nottingham <notting@redhat.com>
- bugfix patches
- fix dependency on /usr/local/bin/perl

* Sat Mar  4 2000 Bill Nottingham <notting@redhat.com>
- 2.3.STABLE2

* Mon Feb 14 2000 Bill Nottingham <notting@redhat.com>
- Yet More Bugfix Patches

* Tue Feb  8 2000 Bill Nottingham <notting@redhat.com>
- add more bugfix patches
- --enable-heap-replacement

* Mon Jan 31 2000 Cristian Gafton <gafton@redhat.com>
- rebuild to fix dependencies

* Fri Jan 28 2000 Bill Nottingham <notting@redhat.com>
- grab some bugfix patches

* Mon Jan 10 2000 Bill Nottingham <notting@redhat.com>
- 2.3.STABLE1 (whee, another serial number)

* Tue Dec 21 1999 Bernhard Rosenkraenzer <bero@redhat.com>
- Fix compliance with ftp RFCs
  (http://www.wu-ftpd.org/broken-clients.html)
- Work around a bug in some versions of autoconf
- BuildPrereq sgml-tools - we're using sgml2html

* Mon Oct 18 1999 Bill Nottingham <notting@redhat.com>
- add a couple of bugfix patches

* Wed Oct 13 1999 Bill Nottingham <notting@redhat.com>
- update to 2.2.STABLE5.
- update FAQ, fix URLs.

* Sat Sep 11 1999 Cristian Gafton <gafton@redhat.com>
- transform restart in reload and add restart to the init script

* Tue Aug 31 1999 Bill Nottingham <notting@redhat.com>
- add squid user as user 23.

* Mon Aug 16 1999 Bill Nottingham <notting@redhat.com>
- initscript munging
- fix conflict between logrotate & squid -k (#4562)

* Wed Jul 28 1999 Bill Nottingham <notting@redhat.com>
- put cachemgr.cgi back in /usr/lib/squid

* Wed Jul 14 1999 Bill Nottingham <notting@redhat.com>
- add webdav bugfix patch (#4027)

* Mon Jul 12 1999 Bill Nottingham <notting@redhat.com>
- fix path to config in squid.init (confuses linuxconf)

* Wed Jul  7 1999 Bill Nottingham <notting@redhat.com>
- 2.2.STABLE4

* Wed Jun 9 1999 Dale Lovelace <dale@redhat.com>
- logrotate changes
- errors from find when /var/spool/squid or
- /var/log/squid didn't exist

* Thu May 20 1999 Bill Nottingham <notting@redhat.com>
- 2.2.STABLE3

* Thu Apr 22 1999 Bill Nottingham <notting@redhat.com>
- update to 2.2.STABLE.2

* Sun Apr 18 1999 Bill Nottingham <notting@redhat.com>
- update to 2.2.STABLE1

* Thu Apr 15 1999 Bill Nottingham <notting@redhat.com>
- don't need to run groupdel on remove
- fix useradd

* Mon Apr 12 1999 Bill Nottingham <notting@redhat.com>
- fix effective_user (bug #2124)

* Mon Apr  5 1999 Bill Nottingham <notting@redhat.com>
- strip binaries

* Thu Apr  1 1999 Bill Nottingham <notting@redhat.com>
- duh. adduser does require a user name.
- add a serial number

* Tue Mar 30 1999 Bill Nottingham <notting@redhat.com>
- add an adduser in %pre, too

* Thu Mar 25 1999 Bill Nottingham <notting@redhat.com>
- oog. chkconfig must be in %preun, not %postun

* Wed Mar 24 1999 Bill Nottingham <notting@redhat.com>
- switch to using group squid
- turn off icmp (insecure)
- update to 2.2.DEVEL3
- build FAQ docs from source

* Tue Mar 23 1999 Bill Nottingham <notting@redhat.com>
- logrotate changes

* Sun Mar 21 1999 Cristian Gafton <gafton@redhat.com> 
- auto rebuild in the new build environment (release 4)

* Wed Feb 10 1999 Bill Nottingham <notting@redhat.com>
- update to 2.2.PRE2

* Wed Dec 30 1998 Bill Nottingham <notting@redhat.com>
- cache & log dirs shouldn't be world readable
- remove preun script (leave logs & cache @ uninstall)

* Tue Dec 29 1998 Bill Nottingham <notting@redhat.com>
- fix initscript to get cache_dir correct

* Fri Dec 18 1998 Bill Nottingham <notting@redhat.com>
- update to 2.1.PATCH2
- merge in some changes from RHCN version

* Sat Oct 10 1998 Cristian Gafton <gafton@redhat.com>
- strip binaries
- version 1.1.22

* Sun May 10 1998 Cristian Gafton <gafton@redhat.com>
- don't make packages conflict with each other...

* Sat May 02 1998 Cristian Gafton <gafton@redhat.com>
- added a proxy auth patch from Alex deVries <adevries@engsoc.carleton.ca>
- fixed initscripts

* Thu Apr 09 1998 Cristian Gafton <gafton@redhat.com>
- rebuilt for Manhattan

* Fri Mar 20 1998 Cristian Gafton <gafton@redhat.com>
- upgraded to 1.1.21/1.NOVM.21

* Mon Mar 02 1998 Cristian Gafton <gafton@redhat.com>
- updated the init script to use reconfigure option to restart squid instead
  of shutdown/restart (both safer and quicker)

* Sat Feb 07 1998 Cristian Gafton <gafton@redhat.com>
- upgraded to 1.1.20
- added the NOVM package and tryied to reduce the mess in the spec file

* Wed Jan 7 1998 Cristian Gafton <gafton@redhat.com>
- first build against glibc
- patched out the use of setresuid(), which is available only on kernels
  2.1.44 and later
